diff --git a/test/boxmodels/3p3c/infiltrationproblem.hh b/test/boxmodels/3p3c/infiltrationproblem.hh
index b0916862f73490d59762e5aa21d3ea1c8f12fda3..ccb206e86150700aa9e99ec90108bb957211dade 100644
--- a/test/boxmodels/3p3c/infiltrationproblem.hh
+++ b/test/boxmodels/3p3c/infiltrationproblem.hh
@@ -183,13 +183,13 @@ public:
      * \brief Returns the temperature within the domain.
      *
      * \param element The element
      * \param fvElemGeom The finite-volume geometry in the box scheme
      * \param scvIdx The local vertex index (SCV index)
      *
      * This problem assumes a temperature of 10 degrees Celsius.
      */
     Scalar boxTemperature(const Element &element,
-                          const FVElementGeometry &fvElemGeom,
+                          const FVElementGeometry &fvGeometry,
                           int scvIdx) const
     {
         return temperature_;
@@ -274,7 +274,7 @@ public:
      *
      * \param values The neumann values for the conservation equations
      * \param element The finite element
      * \param fvElemGeom The finite-volume geometry in the box scheme
      * \param is The intersection between element and boundary
      * \param scvIdx The local vertex index
      * \param boundaryFaceIdx The index of the boundary face
@@ -284,10 +284,10 @@ public:
      */
     void neumann(PrimaryVariables &values,
                  const Element &element,
-                 const FVElementGeometry &fvElemGeom,
+                 const FVElementGeometry &fvGeometry,
                  const Intersection &is,
                  int scvIdx,
-                 int boundaryFaceIdx) const
+                 const int boundaryFaceIdx) const
     {
         const GlobalPosition &globalPos = element.geometry().corner(scvIdx);
         values = 0;
@@ -313,7 +313,7 @@ public:
      *
      * \param values The initial values for the primary variables
      * \param element The finite element
      * \param fvElemGeom The finite-volume geometry in the box scheme
      * \param scvIdx The local vertex index
      *
      * For this method, the \a values parameter stores primary
@@ -321,7 +321,7 @@ public:
      */
     void initial(PrimaryVariables &values,
                  const Element &element,
-                 const FVElementGeometry &fvElemGeom,
+                 const FVElementGeometry &fvGeometry,
                  int scvIdx) const
     {
         const GlobalPosition &globalPos = element.geometry().corner(scvIdx);
@@ -183,13 +183,13 @@ public:
      *
      * \param element The element
-     * \param fvElemGeom The finite-volume geometry in the box scheme
+     * \param fvGeometry The finite-volume geometry in the box scheme
      * \param scvIdx The local vertex index (SCV index)
      *
@@ -274,7 +274,7 @@ public:
      * \param values The neumann values for the conservation equations
      * \param element The finite element
-     * \param fvElemGeom The finite-volume geometry in the box scheme
+     * \param fvGeometry The finite-volume geometry in the box scheme
      * \param is The intersection between element and boundary
      * \param scvIdx The local vertex index
@@ -313,7 +313,7 @@ public:
      * \param values The initial values for the primary variables
      * \param element The finite element
-     * \param fvElemGeom The finite-volume geometry in the box scheme
+     * \param fvGeometry The finite-volume geometry in the box scheme
      * \param scvIdx The local vertex index
      *
diff --git a/test/boxmodels/3p3c/infiltrationspatialparameters.hh b/test/boxmodels/3p3c/infiltrationspatialparameters.hh
index 70015c3b3095d50eac4614b2930a8e5c50feeb33..483a678ae4d51a5a55ca0514348d0ae6b62730bb 100644
--- a/test/boxmodels/3p3c/infiltrationspatialparameters.hh
+++ b/test/boxmodels/3p3c/infiltrationspatialparameters.hh
@@ -30,7 +30,7 @@
 #define DUMUX_INFILTRATION_SPATIAL_PARAMETERS_HH
 
 #include <dumux/boxmodels/3p3c/3p3cindices.hh>
-#include <dumux/material/spatialparameters/boxspatialparameters.hh>
+#include <dumux/material/spatialparams/boxspatialparams.hh>
 #include <dumux/material/fluidmatrixinteractions/3p/parkerVanGen3p.hh>
 #include <dumux/material/fluidmatrixinteractions/3p/parkerVanGen3pparams.hh>
 
@@ -153,14 +153,14 @@ public:
      *        potential gradient.
      *
      * \param element The current finite element
      * \param fvElemGeom The current finite volume geometry of the element
      * \param scvIdx The index of the sub-control volume
      */
     const Scalar intrinsicPermeability(const Element &element,
-                                       const FVElementGeometry &fvElemGeom,
+                                       const FVElementGeometry &fvGeometry,
                                        int scvIdx) const
     {
-        const GlobalPosition &pos = fvElemGeom.subContVol[scvIdx].global;
+        const GlobalPosition &pos = fvGeometry.subContVol[scvIdx].global;
         if (isFineMaterial_(pos))
             return fineK_;
         return coarseK_;
@@ -170,15 +170,15 @@ public:
      * \brief Define the porosity \f$[-]\f$ of the spatial parameters
      *
      * \param element The finite element
      * \param fvElemGeom The finite volume geometry
      * \param scvIdx The local index of the sub-control volume where
      *                    the porosity needs to be defined
      */
     double porosity(const Element &element,
-                    const FVElementGeometry &fvElemGeom,
+                    const FVElementGeometry &fvGeometry,
                     int scvIdx) const
     {
-        //const GlobalPosition &pos = fvElemGeom.subContVol[scvIdx].global;
+        //const GlobalPosition &pos = fvGeometry.subContVol[scvIdx].global;
         // if (isFineMaterial_(pos))
         //     return finePorosity_;
         // else
@@ -191,14 +191,14 @@ public:
      * \brief return the parameter object for the material law which depends on the position
      *
      * \param element The current finite element
      * \param fvElemGeom The current finite volume geometry of the element
      * \param scvIdx The index of the sub-control volume
      */
     const MaterialLawParams& materialLawParams(const Element &element,
-                                               const FVElementGeometry &fvElemGeom,
+                                               const FVElementGeometry &fvGeometry,
                                                int scvIdx) const
     {
-        //const GlobalPosition &pos = fvElemGeom.subContVol[scvIdx].global;
+        //const GlobalPosition &pos = fvGeometry.subContVol[scvIdx].global;
         //if (isFineMaterial_(pos))
         //return fineMaterialParams_;
         //else
@@ -212,18 +212,18 @@ public:
      * This is only required for non-isothermal models.
      *
      * \param element The finite element
      * \param fvElemGeom The finite volume geometry
      * \param scvIdx The local index of the sub-control volume where
      *                    the heat capacity needs to be defined
      */
     double heatCapacity(const Element &element,
-                        const FVElementGeometry &fvElemGeom,
+                        const FVElementGeometry &fvGeometry,
                         int scvIdx) const
     {
         return
             850. // specific heat capacity [J / (kg K)]
             * 2650. // density of sand [kg/m^3]
-            * (1 - porosity(element, fvElemGeom, scvIdx));
+            * (1 - porosity(element, fvGeometry, scvIdx));
     }
 
     /*!
@@ -234,19 +234,19 @@ public:
      *
      * \param heatFlux The resulting heat flux vector
      * \param fluxDat The flux variables
-     * \param vDat The volume variables
+     * \param elemVolVars The volume variables
      * \param tempGrad The temperature gradient
      * \param element The current finite element
      * \param fvElemGeom The finite volume geometry of the current element
      * \param scvfIdx The local index of the sub-control volume face where
      *                    the matrix heat flux should be calculated
      */
     void matrixHeatFlux(Vector &heatFlux,
                         const FluxVariables &fluxDat,
-                        const ElementVolumeVariables &vDat,
+                        const ElementVolumeVariables &elemVolVars,
                         const Vector &tempGrad,
                         const Element &element,
-                        const FVElementGeometry &fvElemGeom,
+                        const FVElementGeometry &fvGeometry,
                         int scvfIdx) const
     {
         static const Scalar ldry = 0.35;
@@ -254,12 +254,12 @@ public:
         static const Scalar lSn1 = 0.65;
 
         // arithmetic mean of the liquid saturation and the porosity
-        const int i = fvElemGeom.subContVolFace[scvfIdx].i;
-        const int j = fvElemGeom.subContVolFace[scvfIdx].j;
-        Scalar Sw = std::max(0.0, (vDat[i].saturation(wPhaseIdx) +
-                                   vDat[j].saturation(wPhaseIdx)) / 2);
-        Scalar Sn = std::max(0.0, (vDat[i].saturation(nPhaseIdx) +
-                                   vDat[j].saturation(nPhaseIdx)) / 2);
+        const int i = fvGeometry.subContVolFace[scvfIdx].i;
+        const int j = fvGeometry.subContVolFace[scvfIdx].j;
+        Scalar Sw = std::max(0.0, (elemVolVars[i].saturation(wPhaseIdx) +
+                                   elemVolVars[j].saturation(wPhaseIdx)) / 2);
+        Scalar Sn = std::max(0.0, (elemVolVars[i].saturation(nPhaseIdx) +
+                                   elemVolVars[j].saturation(nPhaseIdx)) / 2);
 
         // the heat conductivity of the matrix. in general this is a
         // tensorial value, but we assume isotropic heat conductivity.
@@ -153,14 +153,14 @@ public:
      *
      * \param element The current finite element
-     * \param fvElemGeom The current finite volume geometry of the element
+     * \param fvGeometry The current finite volume geometry of the element
      * \param scvIdx The index of the sub-control volume
      */
@@ -170,15 +170,15 @@ public:
      *
      * \param element The finite element
-     * \param fvElemGeom The finite volume geometry
+     * \param fvGeometry The finite volume geometry
      * \param scvIdx The local index of the sub-control volume where
      *                    the porosity needs to be defined
@@ -191,14 +191,14 @@ public:
      *
      * \param element The current finite element
-     * \param fvElemGeom The current finite volume geometry of the element
+     * \param fvGeometry The current finite volume geometry of the element
      * \param scvIdx The index of the sub-control volume
      */
@@ -212,18 +212,18 @@ public:
      *
      * \param element The finite element
-     * \param fvElemGeom The finite volume geometry
+     * \param fvGeometry The finite volume geometry
      * \param scvIdx The local index of the sub-control volume where
      *                    the heat capacity needs to be defined
@@ -234,19 +234,19 @@ public:
      * \param tempGrad The temperature gradient
      * \param element The current finite element
-     * \param fvElemGeom The finite volume geometry of the current element
+     * \param fvGeometry The finite volume geometry of the current element
      * \param scvfIdx The local index of the sub-control volume face where
      *                    the matrix heat flux should be calculated